from setuptools import setup

setup(
    name="cryptoApiSdk",
    version="1.0.6",
    description="",
    long_description='',
    long_description_content_type="text/markdown",
    url="https://github.com/shadow-twitter/sdk.git",
    author="Jared Williams",
    author_email="williamsjared62@gmail.com",
    #To find more licenses or classifiers go to: https://pypi.org/classifiers/
    license="",
    classifiers=[
    ],
    zip_safe=True,
    python_requires=">=3.0",
    py_modules=['cryptoApiSdk'],
    install_requires=['requests']
)
